# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ElasticityAssuranceArgs', 'ElasticityAssurance']

@pulumi.input_type
class ElasticityAssuranceArgs:
    def __init__(__self__, *,
                 instance_amount: pulumi.Input[int],
                 instance_type: pulumi.Input[str],
                 zone_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 assurance_times: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 private_pool_options_match_criteria: Optional[pulumi.Input[str]] = None,
                 private_pool_options_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ElasticityAssurance resource.
        :param pulumi.Input[int] instance_amount: The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        :param pulumi.Input[str] instance_type: Instance type. Currently, only one instance type is supported.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] zone_ids: The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        :param pulumi.Input[str] assurance_times: The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        :param pulumi.Input[str] description: Description of flexible guarantee service.
        :param pulumi.Input[int] period: Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
               - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
               - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        :param pulumi.Input[str] period_unit: Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        :param pulumi.Input[str] private_pool_options_match_criteria: The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        :param pulumi.Input[str] private_pool_options_name: The name of the flexible protection service.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] start_time: Flexible guarantee service effective time.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag key-value pair information bound by the elastic guarantee service.
        """
        pulumi.set(__self__, "instance_amount", instance_amount)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "zone_ids", zone_ids)
        if assurance_times is not None:
            pulumi.set(__self__, "assurance_times", assurance_times)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if private_pool_options_match_criteria is not None:
            pulumi.set(__self__, "private_pool_options_match_criteria", private_pool_options_match_criteria)
        if private_pool_options_name is not None:
            pulumi.set(__self__, "private_pool_options_name", private_pool_options_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> pulumi.Input[int]:
        """
        The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        """
        return pulumi.get(self, "instance_amount")

    @instance_amount.setter
    def instance_amount(self, value: pulumi.Input[int]):
        pulumi.set(self, "instance_amount", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[str]:
        """
        Instance type. Currently, only one instance type is supported.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        """
        return pulumi.get(self, "zone_ids")

    @zone_ids.setter
    def zone_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "zone_ids", value)

    @property
    @pulumi.getter(name="assuranceTimes")
    def assurance_times(self) -> Optional[pulumi.Input[str]]:
        """
        The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        """
        return pulumi.get(self, "assurance_times")

    @assurance_times.setter
    def assurance_times(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assurance_times", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of flexible guarantee service.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
        - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
        - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="privatePoolOptionsMatchCriteria")
    def private_pool_options_match_criteria(self) -> Optional[pulumi.Input[str]]:
        """
        The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        """
        return pulumi.get(self, "private_pool_options_match_criteria")

    @private_pool_options_match_criteria.setter
    def private_pool_options_match_criteria(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_pool_options_match_criteria", value)

    @property
    @pulumi.getter(name="privatePoolOptionsName")
    def private_pool_options_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the flexible protection service.
        """
        return pulumi.get(self, "private_pool_options_name")

    @private_pool_options_name.setter
    def private_pool_options_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_pool_options_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[str]]:
        """
        Flexible guarantee service effective time.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag key-value pair information bound by the elastic guarantee service.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ElasticityAssuranceState:
    def __init__(__self__, *,
                 assurance_times: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 elasticity_assurance_id: Optional[pulumi.Input[str]] = None,
                 end_time: Optional[pulumi.Input[str]] = None,
                 instance_amount: Optional[pulumi.Input[int]] = None,
                 instance_charge_type: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 private_pool_options_match_criteria: Optional[pulumi.Input[str]] = None,
                 private_pool_options_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 start_time_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 used_assurance_times: Optional[pulumi.Input[int]] = None,
                 zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ElasticityAssurance resources.
        :param pulumi.Input[str] assurance_times: The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        :param pulumi.Input[str] description: Description of flexible guarantee service.
        :param pulumi.Input[str] elasticity_assurance_id: The first ID of the resource
        :param pulumi.Input[str] end_time: Flexible guarantee service failure time.
        :param pulumi.Input[int] instance_amount: The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        :param pulumi.Input[str] instance_charge_type: The billing method of the instance. Possible value: PostPaid. Currently, only pay-as-you-go is supported.
        :param pulumi.Input[str] instance_type: Instance type. Currently, only one instance type is supported.
        :param pulumi.Input[int] period: Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
               - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
               - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        :param pulumi.Input[str] period_unit: Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        :param pulumi.Input[str] private_pool_options_match_criteria: The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        :param pulumi.Input[str] private_pool_options_name: The name of the flexible protection service.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] start_time: Flexible guarantee service effective time.
        :param pulumi.Input[str] start_time_type: Flexible guarantee effective way. Possible values:-Now: Effective immediately.-Later: the specified time takes effect.
        :param pulumi.Input[str] status: The status of flexible guarantee services. Possible values:-Preparing: in preparation.-Prepared: to take effect.-Active: in effect.-Released: Released.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag key-value pair information bound by the elastic guarantee service.
        :param pulumi.Input[int] used_assurance_times: This parameter is not yet available.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] zone_ids: The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        """
        if assurance_times is not None:
            pulumi.set(__self__, "assurance_times", assurance_times)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if elasticity_assurance_id is not None:
            pulumi.set(__self__, "elasticity_assurance_id", elasticity_assurance_id)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if instance_amount is not None:
            pulumi.set(__self__, "instance_amount", instance_amount)
        if instance_charge_type is not None:
            pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if private_pool_options_match_criteria is not None:
            pulumi.set(__self__, "private_pool_options_match_criteria", private_pool_options_match_criteria)
        if private_pool_options_name is not None:
            pulumi.set(__self__, "private_pool_options_name", private_pool_options_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if start_time_type is not None:
            pulumi.set(__self__, "start_time_type", start_time_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if used_assurance_times is not None:
            pulumi.set(__self__, "used_assurance_times", used_assurance_times)
        if zone_ids is not None:
            pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="assuranceTimes")
    def assurance_times(self) -> Optional[pulumi.Input[str]]:
        """
        The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        """
        return pulumi.get(self, "assurance_times")

    @assurance_times.setter
    def assurance_times(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assurance_times", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of flexible guarantee service.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="elasticityAssuranceId")
    def elasticity_assurance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "elasticity_assurance_id")

    @elasticity_assurance_id.setter
    def elasticity_assurance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "elasticity_assurance_id", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[str]]:
        """
        Flexible guarantee service failure time.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> Optional[pulumi.Input[int]]:
        """
        The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        """
        return pulumi.get(self, "instance_amount")

    @instance_amount.setter
    def instance_amount(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "instance_amount", value)

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing method of the instance. Possible value: PostPaid. Currently, only pay-as-you-go is supported.
        """
        return pulumi.get(self, "instance_charge_type")

    @instance_charge_type.setter
    def instance_charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_charge_type", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        Instance type. Currently, only one instance type is supported.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
        - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
        - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="privatePoolOptionsMatchCriteria")
    def private_pool_options_match_criteria(self) -> Optional[pulumi.Input[str]]:
        """
        The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        """
        return pulumi.get(self, "private_pool_options_match_criteria")

    @private_pool_options_match_criteria.setter
    def private_pool_options_match_criteria(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_pool_options_match_criteria", value)

    @property
    @pulumi.getter(name="privatePoolOptionsName")
    def private_pool_options_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the flexible protection service.
        """
        return pulumi.get(self, "private_pool_options_name")

    @private_pool_options_name.setter
    def private_pool_options_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_pool_options_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[str]]:
        """
        Flexible guarantee service effective time.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter(name="startTimeType")
    def start_time_type(self) -> Optional[pulumi.Input[str]]:
        """
        Flexible guarantee effective way. Possible values:-Now: Effective immediately.-Later: the specified time takes effect.
        """
        return pulumi.get(self, "start_time_type")

    @start_time_type.setter
    def start_time_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of flexible guarantee services. Possible values:-Preparing: in preparation.-Prepared: to take effect.-Active: in effect.-Released: Released.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag key-value pair information bound by the elastic guarantee service.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="usedAssuranceTimes")
    def used_assurance_times(self) -> Optional[pulumi.Input[int]]:
        """
        This parameter is not yet available.
        """
        return pulumi.get(self, "used_assurance_times")

    @used_assurance_times.setter
    def used_assurance_times(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "used_assurance_times", value)

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        """
        return pulumi.get(self, "zone_ids")

    @zone_ids.setter
    def zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "zone_ids", value)


class ElasticityAssurance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assurance_times: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 instance_amount: Optional[pulumi.Input[int]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 private_pool_options_match_criteria: Optional[pulumi.Input[str]] = None,
                 private_pool_options_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a Ecs Elasticity Assurance resource.

        For information about Ecs Elasticity Assurance and how to use it, see [What is Elasticity Assurance](https://www.alibabacloud.com/help/en/elastic-compute-service/latest/createelasticityassurance).

        > **NOTE:** Available in v1.196.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_get_zones = alicloud.get_zones(available_resource_creation="Instance")
        default_get_instance_types = alicloud.ecs.get_instance_types(instance_type_family="ecs.c6")
        default_elasticity_assurance = alicloud.ecs.ElasticityAssurance("default",
            instance_amount=1,
            description="before",
            zone_ids=[default_get_zones.zones[2].id],
            private_pool_options_name="test_before",
            period=1,
            private_pool_options_match_criteria="Open",
            instance_type=default_get_instance_types.instance_types[0].id,
            period_unit="Month",
            assurance_times="Unlimited",
            resource_group_id=default.ids[0])
        ```

        ## Import

        Ecs Elasticity Assurance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/elasticityAssurance:ElasticityAssurance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] assurance_times: The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        :param pulumi.Input[str] description: Description of flexible guarantee service.
        :param pulumi.Input[int] instance_amount: The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        :param pulumi.Input[str] instance_type: Instance type. Currently, only one instance type is supported.
        :param pulumi.Input[int] period: Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
               - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
               - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        :param pulumi.Input[str] period_unit: Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        :param pulumi.Input[str] private_pool_options_match_criteria: The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        :param pulumi.Input[str] private_pool_options_name: The name of the flexible protection service.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] start_time: Flexible guarantee service effective time.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag key-value pair information bound by the elastic guarantee service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] zone_ids: The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ElasticityAssuranceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Ecs Elasticity Assurance resource.

        For information about Ecs Elasticity Assurance and how to use it, see [What is Elasticity Assurance](https://www.alibabacloud.com/help/en/elastic-compute-service/latest/createelasticityassurance).

        > **NOTE:** Available in v1.196.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_get_zones = alicloud.get_zones(available_resource_creation="Instance")
        default_get_instance_types = alicloud.ecs.get_instance_types(instance_type_family="ecs.c6")
        default_elasticity_assurance = alicloud.ecs.ElasticityAssurance("default",
            instance_amount=1,
            description="before",
            zone_ids=[default_get_zones.zones[2].id],
            private_pool_options_name="test_before",
            period=1,
            private_pool_options_match_criteria="Open",
            instance_type=default_get_instance_types.instance_types[0].id,
            period_unit="Month",
            assurance_times="Unlimited",
            resource_group_id=default.ids[0])
        ```

        ## Import

        Ecs Elasticity Assurance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/elasticityAssurance:ElasticityAssurance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ElasticityAssuranceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ElasticityAssuranceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assurance_times: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 instance_amount: Optional[pulumi.Input[int]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 period_unit: Optional[pulumi.Input[str]] = None,
                 private_pool_options_match_criteria: Optional[pulumi.Input[str]] = None,
                 private_pool_options_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ElasticityAssuranceArgs.__new__(ElasticityAssuranceArgs)

            __props__.__dict__["assurance_times"] = assurance_times
            __props__.__dict__["description"] = description
            if instance_amount is None and not opts.urn:
                raise TypeError("Missing required property 'instance_amount'")
            __props__.__dict__["instance_amount"] = instance_amount
            if instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type'")
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["private_pool_options_match_criteria"] = private_pool_options_match_criteria
            __props__.__dict__["private_pool_options_name"] = private_pool_options_name
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["start_time"] = start_time
            __props__.__dict__["tags"] = tags
            if zone_ids is None and not opts.urn:
                raise TypeError("Missing required property 'zone_ids'")
            __props__.__dict__["zone_ids"] = zone_ids
            __props__.__dict__["elasticity_assurance_id"] = None
            __props__.__dict__["end_time"] = None
            __props__.__dict__["instance_charge_type"] = None
            __props__.__dict__["start_time_type"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["used_assurance_times"] = None
        super(ElasticityAssurance, __self__).__init__(
            'alicloud:ecs/elasticityAssurance:ElasticityAssurance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            assurance_times: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            elasticity_assurance_id: Optional[pulumi.Input[str]] = None,
            end_time: Optional[pulumi.Input[str]] = None,
            instance_amount: Optional[pulumi.Input[int]] = None,
            instance_charge_type: Optional[pulumi.Input[str]] = None,
            instance_type: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            period_unit: Optional[pulumi.Input[str]] = None,
            private_pool_options_match_criteria: Optional[pulumi.Input[str]] = None,
            private_pool_options_name: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            start_time: Optional[pulumi.Input[str]] = None,
            start_time_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            used_assurance_times: Optional[pulumi.Input[int]] = None,
            zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'ElasticityAssurance':
        """
        Get an existing ElasticityAssurance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] assurance_times: The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        :param pulumi.Input[str] description: Description of flexible guarantee service.
        :param pulumi.Input[str] elasticity_assurance_id: The first ID of the resource
        :param pulumi.Input[str] end_time: Flexible guarantee service failure time.
        :param pulumi.Input[int] instance_amount: The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        :param pulumi.Input[str] instance_charge_type: The billing method of the instance. Possible value: PostPaid. Currently, only pay-as-you-go is supported.
        :param pulumi.Input[str] instance_type: Instance type. Currently, only one instance type is supported.
        :param pulumi.Input[int] period: Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
               - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
               - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        :param pulumi.Input[str] period_unit: Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        :param pulumi.Input[str] private_pool_options_match_criteria: The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        :param pulumi.Input[str] private_pool_options_name: The name of the flexible protection service.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] start_time: Flexible guarantee service effective time.
        :param pulumi.Input[str] start_time_type: Flexible guarantee effective way. Possible values:-Now: Effective immediately.-Later: the specified time takes effect.
        :param pulumi.Input[str] status: The status of flexible guarantee services. Possible values:-Preparing: in preparation.-Prepared: to take effect.-Active: in effect.-Released: Released.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag key-value pair information bound by the elastic guarantee service.
        :param pulumi.Input[int] used_assurance_times: This parameter is not yet available.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] zone_ids: The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ElasticityAssuranceState.__new__(_ElasticityAssuranceState)

        __props__.__dict__["assurance_times"] = assurance_times
        __props__.__dict__["description"] = description
        __props__.__dict__["elasticity_assurance_id"] = elasticity_assurance_id
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["instance_amount"] = instance_amount
        __props__.__dict__["instance_charge_type"] = instance_charge_type
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["private_pool_options_match_criteria"] = private_pool_options_match_criteria
        __props__.__dict__["private_pool_options_name"] = private_pool_options_name
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["start_time_type"] = start_time_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["used_assurance_times"] = used_assurance_times
        __props__.__dict__["zone_ids"] = zone_ids
        return ElasticityAssurance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="assuranceTimes")
    def assurance_times(self) -> pulumi.Output[str]:
        """
        The total number of times that the elasticity assurance can be applied. Set the value to Unlimited. This value indicates that the elasticity assurance can be applied an unlimited number of times within its effective duration. Default value: Unlimited.
        """
        return pulumi.get(self, "assurance_times")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of flexible guarantee service.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="elasticityAssuranceId")
    def elasticity_assurance_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "elasticity_assurance_id")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[str]:
        """
        Flexible guarantee service failure time.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> pulumi.Output[int]:
        """
        The total number of instances for which to reserve the capacity of an instance type. Valid values: 1 to 1000.
        """
        return pulumi.get(self, "instance_amount")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> pulumi.Output[str]:
        """
        The billing method of the instance. Possible value: PostPaid. Currently, only pay-as-you-go is supported.
        """
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        """
        Instance type. Currently, only one instance type is supported.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        Length of purchase. The unit of duration is determined by the 'period_unit' parameter. Default value: 1.
        - When the `period_unit` parameter is set to Month, the valid values are 1, 2, 3, 4, 5, 6, 7, 8, and 9.
        - When the `period_unit` parameter is set to Year, the valid values are 1, 2, 3, 4, and 5.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[Optional[str]]:
        """
        Duration unit. Value range:-Month: Month-Year: YearDefault value: Year
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="privatePoolOptionsMatchCriteria")
    def private_pool_options_match_criteria(self) -> pulumi.Output[str]:
        """
        The matching mode of flexible guarantee service. Possible values:-Open: flexible guarantee service for Open mode.-Target: specifies the flexible guarantee service of the mode.
        """
        return pulumi.get(self, "private_pool_options_match_criteria")

    @property
    @pulumi.getter(name="privatePoolOptionsName")
    def private_pool_options_name(self) -> pulumi.Output[str]:
        """
        The name of the flexible protection service.
        """
        return pulumi.get(self, "private_pool_options_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[str]:
        """
        Flexible guarantee service effective time.
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter(name="startTimeType")
    def start_time_type(self) -> pulumi.Output[str]:
        """
        Flexible guarantee effective way. Possible values:-Now: Effective immediately.-Later: the specified time takes effect.
        """
        return pulumi.get(self, "start_time_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of flexible guarantee services. Possible values:-Preparing: in preparation.-Prepared: to take effect.-Active: in effect.-Released: Released.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The tag key-value pair information bound by the elastic guarantee service.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="usedAssuranceTimes")
    def used_assurance_times(self) -> pulumi.Output[int]:
        """
        This parameter is not yet available.
        """
        return pulumi.get(self, "used_assurance_times")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        The zone ID of the region to which the elastic Protection Service belongs. Currently, only the creation of flexible protection services in one available area is supported.
        """
        return pulumi.get(self, "zone_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RoleAttachmentArgs', 'RoleAttachment']

@pulumi.input_type
class RoleAttachmentArgs:
    def __init__(__self__, *,
                 instance_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 role_name: pulumi.Input[str]):
        """
        The set of arguments for constructing a RoleAttachment resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] instance_ids: The list of ECS instance's IDs.
        :param pulumi.Input[str] role_name: The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        pulumi.set(__self__, "instance_ids", instance_ids)
        pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The list of ECS instance's IDs.
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[str]:
        """
        The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_name", value)


@pulumi.input_type
class _RoleAttachmentState:
    def __init__(__self__, *,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RoleAttachment resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] instance_ids: The list of ECS instance's IDs.
        :param pulumi.Input[str] role_name: The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ECS instance's IDs.
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_name", value)


class RoleAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a RAM role attachment resource to bind role for several ECS instances.

        > **NOTE:** Available since v1.0.0+.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
            cpu_core_count=2,
            memory_size=4)
        default_get_images = alicloud.ecs.get_images(name_regex="^ubuntu_18.*64",
            most_recent=True,
            owners="system")
        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "ecsInstanceVPCExample"
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=name)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_security_group_rule = alicloud.ecs.SecurityGroupRule("default",
            type="ingress",
            ip_protocol="tcp",
            nic_type="intranet",
            policy="accept",
            port_range="22/22",
            priority=1,
            security_group_id=default_security_group.id,
            cidr_ip="172.16.0.0/24")
        foo = alicloud.ecs.Instance("foo",
            vswitch_id=default_switch.id,
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            system_disk_category="cloud_efficiency",
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=5,
            security_groups=[default_security_group.id],
            instance_name=name)
        role = alicloud.ram.Role("role",
            name="terraform-example",
            document=\"\"\"  {
            "Statement": [
              {
                "Action": "sts:AssumeRole",
                "Effect": "Allow",
                "Principal": {
                  "Service": [
                    "ecs.aliyuncs.com"
                  ]
                }
              }
            ],
            "Version": "1"
          }

        \"\"\",
            description="this is a test",
            force=True)
        attach = alicloud.ram.RoleAttachment("attach",
            role_name=role.name,
            instance_ids=[__item.id for __item in [foo]])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] instance_ids: The list of ECS instance's IDs.
        :param pulumi.Input[str] role_name: The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RAM role attachment resource to bind role for several ECS instances.

        > **NOTE:** Available since v1.0.0+.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
            cpu_core_count=2,
            memory_size=4)
        default_get_images = alicloud.ecs.get_images(name_regex="^ubuntu_18.*64",
            most_recent=True,
            owners="system")
        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "ecsInstanceVPCExample"
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=name)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_security_group_rule = alicloud.ecs.SecurityGroupRule("default",
            type="ingress",
            ip_protocol="tcp",
            nic_type="intranet",
            policy="accept",
            port_range="22/22",
            priority=1,
            security_group_id=default_security_group.id,
            cidr_ip="172.16.0.0/24")
        foo = alicloud.ecs.Instance("foo",
            vswitch_id=default_switch.id,
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            system_disk_category="cloud_efficiency",
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=5,
            security_groups=[default_security_group.id],
            instance_name=name)
        role = alicloud.ram.Role("role",
            name="terraform-example",
            document=\"\"\"  {
            "Statement": [
              {
                "Action": "sts:AssumeRole",
                "Effect": "Allow",
                "Principal": {
                  "Service": [
                    "ecs.aliyuncs.com"
                  ]
                }
              }
            ],
            "Version": "1"
          }

        \"\"\",
            description="this is a test",
            force=True)
        attach = alicloud.ram.RoleAttachment("attach",
            role_name=role.name,
            instance_ids=[__item.id for __item in [foo]])
        ```

        :param str resource_name: The name of the resource.
        :param RoleAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleAttachmentArgs.__new__(RoleAttachmentArgs)

            if instance_ids is None and not opts.urn:
                raise TypeError("Missing required property 'instance_ids'")
            __props__.__dict__["instance_ids"] = instance_ids
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
        super(RoleAttachment, __self__).__init__(
            'alicloud:ram/roleAttachment:RoleAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            role_name: Optional[pulumi.Input[str]] = None) -> 'RoleAttachment':
        """
        Get an existing RoleAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] instance_ids: The list of ECS instance's IDs.
        :param pulumi.Input[str] role_name: The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleAttachmentState.__new__(_RoleAttachmentState)

        __props__.__dict__["instance_ids"] = instance_ids
        __props__.__dict__["role_name"] = role_name
        return RoleAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        The list of ECS instance's IDs.
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[str]:
        """
        The name of role used to bind. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-", "_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "role_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomPropertyArgs', 'CustomProperty']

@pulumi.input_type
class CustomPropertyArgs:
    def __init__(__self__, *,
                 property_key: pulumi.Input[str],
                 property_values: Optional[pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]]] = None):
        """
        The set of arguments for constructing a CustomProperty resource.
        :param pulumi.Input[str] property_key: The Custom attribute key.
        :param pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]] property_values: Custom attribute sets the value of. See `property_values` below.
        """
        pulumi.set(__self__, "property_key", property_key)
        if property_values is not None:
            pulumi.set(__self__, "property_values", property_values)

    @property
    @pulumi.getter(name="propertyKey")
    def property_key(self) -> pulumi.Input[str]:
        """
        The Custom attribute key.
        """
        return pulumi.get(self, "property_key")

    @property_key.setter
    def property_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "property_key", value)

    @property
    @pulumi.getter(name="propertyValues")
    def property_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]]]:
        """
        Custom attribute sets the value of. See `property_values` below.
        """
        return pulumi.get(self, "property_values")

    @property_values.setter
    def property_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]]]):
        pulumi.set(self, "property_values", value)


@pulumi.input_type
class _CustomPropertyState:
    def __init__(__self__, *,
                 property_key: Optional[pulumi.Input[str]] = None,
                 property_values: Optional[pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]]] = None):
        """
        Input properties used for looking up and filtering CustomProperty resources.
        :param pulumi.Input[str] property_key: The Custom attribute key.
        :param pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]] property_values: Custom attribute sets the value of. See `property_values` below.
        """
        if property_key is not None:
            pulumi.set(__self__, "property_key", property_key)
        if property_values is not None:
            pulumi.set(__self__, "property_values", property_values)

    @property
    @pulumi.getter(name="propertyKey")
    def property_key(self) -> Optional[pulumi.Input[str]]:
        """
        The Custom attribute key.
        """
        return pulumi.get(self, "property_key")

    @property_key.setter
    def property_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "property_key", value)

    @property
    @pulumi.getter(name="propertyValues")
    def property_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]]]:
        """
        Custom attribute sets the value of. See `property_values` below.
        """
        return pulumi.get(self, "property_values")

    @property_values.setter
    def property_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomPropertyPropertyValueArgs']]]]):
        pulumi.set(self, "property_values", value)


class CustomProperty(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 property_key: Optional[pulumi.Input[str]] = None,
                 property_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomPropertyPropertyValueArgs', 'CustomPropertyPropertyValueArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a ECD Custom Property resource.

        For information about ECD Custom Property and how to use it, see [What is Custom Property](https://www.alibabacloud.com/help/en/wuying-workspace/developer-reference/api-eds-user-2021-03-08-createproperty-desktop).

        > **NOTE:** Available since v1.176.0.

        > **NOTE:** Up to 10 different attributes can be created under an alibaba cloud account. Up to 50 different attribute values can be added under an attribute.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.eds.CustomProperty("example",
            property_key="example_key",
            property_values=[{
                "property_value": "example_value",
            }])
        ```

        ## Import

        ECD Custom Property can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eds/customProperty:CustomProperty example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] property_key: The Custom attribute key.
        :param pulumi.Input[Sequence[pulumi.Input[Union['CustomPropertyPropertyValueArgs', 'CustomPropertyPropertyValueArgsDict']]]] property_values: Custom attribute sets the value of. See `property_values` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomPropertyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECD Custom Property resource.

        For information about ECD Custom Property and how to use it, see [What is Custom Property](https://www.alibabacloud.com/help/en/wuying-workspace/developer-reference/api-eds-user-2021-03-08-createproperty-desktop).

        > **NOTE:** Available since v1.176.0.

        > **NOTE:** Up to 10 different attributes can be created under an alibaba cloud account. Up to 50 different attribute values can be added under an attribute.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.eds.CustomProperty("example",
            property_key="example_key",
            property_values=[{
                "property_value": "example_value",
            }])
        ```

        ## Import

        ECD Custom Property can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eds/customProperty:CustomProperty example <id>
        ```

        :param str resource_name: The name of the resource.
        :param CustomPropertyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomPropertyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 property_key: Optional[pulumi.Input[str]] = None,
                 property_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomPropertyPropertyValueArgs', 'CustomPropertyPropertyValueArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomPropertyArgs.__new__(CustomPropertyArgs)

            if property_key is None and not opts.urn:
                raise TypeError("Missing required property 'property_key'")
            __props__.__dict__["property_key"] = property_key
            __props__.__dict__["property_values"] = property_values
        super(CustomProperty, __self__).__init__(
            'alicloud:eds/customProperty:CustomProperty',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            property_key: Optional[pulumi.Input[str]] = None,
            property_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomPropertyPropertyValueArgs', 'CustomPropertyPropertyValueArgsDict']]]]] = None) -> 'CustomProperty':
        """
        Get an existing CustomProperty resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] property_key: The Custom attribute key.
        :param pulumi.Input[Sequence[pulumi.Input[Union['CustomPropertyPropertyValueArgs', 'CustomPropertyPropertyValueArgsDict']]]] property_values: Custom attribute sets the value of. See `property_values` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomPropertyState.__new__(_CustomPropertyState)

        __props__.__dict__["property_key"] = property_key
        __props__.__dict__["property_values"] = property_values
        return CustomProperty(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="propertyKey")
    def property_key(self) -> pulumi.Output[str]:
        """
        The Custom attribute key.
        """
        return pulumi.get(self, "property_key")

    @property
    @pulumi.getter(name="propertyValues")
    def property_values(self) -> pulumi.Output[Optional[Sequence['outputs.CustomPropertyPropertyValue']]]:
        """
        Custom attribute sets the value of. See `property_values` below.
        """
        return pulumi.get(self, "property_values")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDiskReplicaPairsResult',
    'AwaitableGetDiskReplicaPairsResult',
    'get_disk_replica_pairs',
    'get_disk_replica_pairs_output',
]

@pulumi.output_type
class GetDiskReplicaPairsResult:
    """
    A collection of values returned by getDiskReplicaPairs.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, pairs=None, replica_group_id=None, site=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if pairs and not isinstance(pairs, list):
            raise TypeError("Expected argument 'pairs' to be a list")
        pulumi.set(__self__, "pairs", pairs)
        if replica_group_id and not isinstance(replica_group_id, str):
            raise TypeError("Expected argument 'replica_group_id' to be a str")
        pulumi.set(__self__, "replica_group_id", replica_group_id)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Disk Replica Pair IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def pairs(self) -> Sequence['outputs.GetDiskReplicaPairsPairResult']:
        """
        A list of Disk Replica Pair Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "pairs")

    @property
    @pulumi.getter(name="replicaGroupId")
    def replica_group_id(self) -> Optional[str]:
        return pulumi.get(self, "replica_group_id")

    @property
    @pulumi.getter
    def site(self) -> Optional[str]:
        return pulumi.get(self, "site")


class AwaitableGetDiskReplicaPairsResult(GetDiskReplicaPairsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDiskReplicaPairsResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            pairs=self.pairs,
            replica_group_id=self.replica_group_id,
            site=self.site)


def get_disk_replica_pairs(ids: Optional[Sequence[str]] = None,
                           output_file: Optional[str] = None,
                           replica_group_id: Optional[str] = None,
                           site: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDiskReplicaPairsResult:
    """
    This data source provides Ebs Disk Replica Pair available to the user.

    > **NOTE:** Available in 1.196.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.ebs.get_disk_replica_pairs(ids=[default_alicloud_ebs_disk_replica_pair["id"]])
    pulumi.export("alicloudEbsDiskReplicaPairExampleId", default.pairs[0].id)
    ```


    :param Sequence[str] ids: A list of Disk Replica Pair IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str replica_group_id: Consistent Replication Group ID, you can specify a consistent replication group ID to query the replication pairs within the group.
    :param str site: Get data for replication pairs where this Region is the production site or the disaster recovery site.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['replicaGroupId'] = replica_group_id
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ebs/getDiskReplicaPairs:getDiskReplicaPairs', __args__, opts=opts, typ=GetDiskReplicaPairsResult).value

    return AwaitableGetDiskReplicaPairsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        pairs=pulumi.get(__ret__, 'pairs'),
        replica_group_id=pulumi.get(__ret__, 'replica_group_id'),
        site=pulumi.get(__ret__, 'site'))
def get_disk_replica_pairs_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  replica_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  site: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDiskReplicaPairsResult]:
    """
    This data source provides Ebs Disk Replica Pair available to the user.

    > **NOTE:** Available in 1.196.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.ebs.get_disk_replica_pairs(ids=[default_alicloud_ebs_disk_replica_pair["id"]])
    pulumi.export("alicloudEbsDiskReplicaPairExampleId", default.pairs[0].id)
    ```


    :param Sequence[str] ids: A list of Disk Replica Pair IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str replica_group_id: Consistent Replication Group ID, you can specify a consistent replication group ID to query the replication pairs within the group.
    :param str site: Get data for replication pairs where this Region is the production site or the disaster recovery site.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['replicaGroupId'] = replica_group_id
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ebs/getDiskReplicaPairs:getDiskReplicaPairs', __args__, opts=opts, typ=GetDiskReplicaPairsResult)
    return __ret__.apply(lambda __response__: GetDiskReplicaPairsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        pairs=pulumi.get(__response__, 'pairs'),
        replica_group_id=pulumi.get(__response__, 'replica_group_id'),
        site=pulumi.get(__response__, 'site')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceDataDiskArgs',
    'InstanceDataDiskArgsDict',
    'InstanceSystemDiskArgs',
    'InstanceSystemDiskArgsDict',
    'LoadBalancerBackendServerArgs',
    'LoadBalancerBackendServerArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceDataDiskArgsDict(TypedDict):
        category: NotRequired[pulumi.Input[str]]
        """
        Data disk type. Optional values:
        - cloud_efficiency: Ultra cloud disk
        - cloud_ssd: Full Flash cloud disk
        - local_hdd: local hdd disk
        - local_ssd: local disk ssd.
        """
        disk_id: NotRequired[pulumi.Input[str]]
        """
        Cloud Disk ID.
        """
        encrypt_key_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the KMS key used by the cloud disk.
        """
        encrypted: NotRequired[pulumi.Input[bool]]
        """
        Whether to encrypt the cloud disk. Value range:  true: Yes  false (default): No.
        """
        size: NotRequired[pulumi.Input[int]]
        """
        Data disk size, unit: GB.
        """
elif False:
    InstanceDataDiskArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceDataDiskArgs:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[str]] = None,
                 disk_id: Optional[pulumi.Input[str]] = None,
                 encrypt_key_id: Optional[pulumi.Input[str]] = None,
                 encrypted: Optional[pulumi.Input[bool]] = None,
                 size: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] category: Data disk type. Optional values:
               - cloud_efficiency: Ultra cloud disk
               - cloud_ssd: Full Flash cloud disk
               - local_hdd: local hdd disk
               - local_ssd: local disk ssd.
        :param pulumi.Input[str] disk_id: Cloud Disk ID.
        :param pulumi.Input[str] encrypt_key_id: The ID of the KMS key used by the cloud disk.
        :param pulumi.Input[bool] encrypted: Whether to encrypt the cloud disk. Value range:  true: Yes  false (default): No.
        :param pulumi.Input[int] size: Data disk size, unit: GB.
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if disk_id is not None:
            pulumi.set(__self__, "disk_id", disk_id)
        if encrypt_key_id is not None:
            pulumi.set(__self__, "encrypt_key_id", encrypt_key_id)
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[str]]:
        """
        Data disk type. Optional values:
        - cloud_efficiency: Ultra cloud disk
        - cloud_ssd: Full Flash cloud disk
        - local_hdd: local hdd disk
        - local_ssd: local disk ssd.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="diskId")
    def disk_id(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud Disk ID.
        """
        return pulumi.get(self, "disk_id")

    @disk_id.setter
    def disk_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_id", value)

    @property
    @pulumi.getter(name="encryptKeyId")
    def encrypt_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the KMS key used by the cloud disk.
        """
        return pulumi.get(self, "encrypt_key_id")

    @encrypt_key_id.setter
    def encrypt_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypt_key_id", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to encrypt the cloud disk. Value range:  true: Yes  false (default): No.
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[int]]:
        """
        Data disk size, unit: GB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)


if not MYPY:
    class InstanceSystemDiskArgsDict(TypedDict):
        category: NotRequired[pulumi.Input[str]]
        """
        System disk type. Value
        - cloud_efficiency: Ultra cloud disk
        - cloud_ssd: Full Flash cloud disk
        - local_hdd: local hdd disk
        - local_ssd: local disk ssd.
        """
        size: NotRequired[pulumi.Input[int]]
        """
        System disk size, unit: GB.
        """
elif False:
    InstanceSystemDiskArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceSystemDiskArgs:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] category: System disk type. Value
               - cloud_efficiency: Ultra cloud disk
               - cloud_ssd: Full Flash cloud disk
               - local_hdd: local hdd disk
               - local_ssd: local disk ssd.
        :param pulumi.Input[int] size: System disk size, unit: GB.
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[str]]:
        """
        System disk type. Value
        - cloud_efficiency: Ultra cloud disk
        - cloud_ssd: Full Flash cloud disk
        - local_hdd: local hdd disk
        - local_ssd: local disk ssd.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[int]]:
        """
        System disk size, unit: GB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)


if not MYPY:
    class LoadBalancerBackendServerArgsDict(TypedDict):
        server_id: pulumi.Input[str]
        """
        Backend server instance ID  Example value: i-5vb5h5njxiuhn48a * * * *.
        """
        ip: NotRequired[pulumi.Input[str]]
        """
        IP address of the backend server  Example value: 192.168.0.5.
        """
        port: NotRequired[pulumi.Input[int]]
        """
        Port used by the backend server.
        """
        type: NotRequired[pulumi.Input[str]]
        """
        Backend server type  Example value: ens.
        """
        weight: NotRequired[pulumi.Input[int]]
        """
        Weight of the backend server  Example value: 100.
        """
elif False:
    LoadBalancerBackendServerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LoadBalancerBackendServerArgs:
    def __init__(__self__, *,
                 server_id: pulumi.Input[str],
                 ip: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] server_id: Backend server instance ID  Example value: i-5vb5h5njxiuhn48a * * * *.
        :param pulumi.Input[str] ip: IP address of the backend server  Example value: 192.168.0.5.
        :param pulumi.Input[int] port: Port used by the backend server.
        :param pulumi.Input[str] type: Backend server type  Example value: ens.
        :param pulumi.Input[int] weight: Weight of the backend server  Example value: 100.
        """
        pulumi.set(__self__, "server_id", server_id)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Input[str]:
        """
        Backend server instance ID  Example value: i-5vb5h5njxiuhn48a * * * *.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "server_id", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[str]]:
        """
        IP address of the backend server  Example value: 192.168.0.5.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        Port used by the backend server.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Backend server type  Example value: ens.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        Weight of the backend server  Example value: 100.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'LakeAccountAccountPrivilegeArgs',
    'LakeAccountAccountPrivilegeArgsDict',
    'LakeAccountAccountPrivilegePrivilegeObjectArgs',
    'LakeAccountAccountPrivilegePrivilegeObjectArgsDict',
]

MYPY = False

if not MYPY:
    class LakeAccountAccountPrivilegeArgsDict(TypedDict):
        privilege_object: NotRequired[pulumi.Input['LakeAccountAccountPrivilegePrivilegeObjectArgsDict']]
        """
        Object associated to privileges. See `privilege_object` below.
        """
        privilege_type: NotRequired[pulumi.Input[str]]
        """
        The type of privileges.
        """
        privileges: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        privilege list.
        """
elif False:
    LakeAccountAccountPrivilegeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LakeAccountAccountPrivilegeArgs:
    def __init__(__self__, *,
                 privilege_object: Optional[pulumi.Input['LakeAccountAccountPrivilegePrivilegeObjectArgs']] = None,
                 privilege_type: Optional[pulumi.Input[str]] = None,
                 privileges: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input['LakeAccountAccountPrivilegePrivilegeObjectArgs'] privilege_object: Object associated to privileges. See `privilege_object` below.
        :param pulumi.Input[str] privilege_type: The type of privileges.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] privileges: privilege list.
        """
        if privilege_object is not None:
            pulumi.set(__self__, "privilege_object", privilege_object)
        if privilege_type is not None:
            pulumi.set(__self__, "privilege_type", privilege_type)
        if privileges is not None:
            pulumi.set(__self__, "privileges", privileges)

    @property
    @pulumi.getter(name="privilegeObject")
    def privilege_object(self) -> Optional[pulumi.Input['LakeAccountAccountPrivilegePrivilegeObjectArgs']]:
        """
        Object associated to privileges. See `privilege_object` below.
        """
        return pulumi.get(self, "privilege_object")

    @privilege_object.setter
    def privilege_object(self, value: Optional[pulumi.Input['LakeAccountAccountPrivilegePrivilegeObjectArgs']]):
        pulumi.set(self, "privilege_object", value)

    @property
    @pulumi.getter(name="privilegeType")
    def privilege_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of privileges.
        """
        return pulumi.get(self, "privilege_type")

    @privilege_type.setter
    def privilege_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "privilege_type", value)

    @property
    @pulumi.getter
    def privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        privilege list.
        """
        return pulumi.get(self, "privileges")

    @privileges.setter
    def privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "privileges", value)


if not MYPY:
    class LakeAccountAccountPrivilegePrivilegeObjectArgsDict(TypedDict):
        column: NotRequired[pulumi.Input[str]]
        """
        The name of column.
        """
        database: NotRequired[pulumi.Input[str]]
        """
        The name of database.
        """
        table: NotRequired[pulumi.Input[str]]
        """
        The name of table.
        """
elif False:
    LakeAccountAccountPrivilegePrivilegeObjectArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LakeAccountAccountPrivilegePrivilegeObjectArgs:
    def __init__(__self__, *,
                 column: Optional[pulumi.Input[str]] = None,
                 database: Optional[pulumi.Input[str]] = None,
                 table: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] column: The name of column.
        :param pulumi.Input[str] database: The name of database.
        :param pulumi.Input[str] table: The name of table.
        """
        if column is not None:
            pulumi.set(__self__, "column", column)
        if database is not None:
            pulumi.set(__self__, "database", database)
        if table is not None:
            pulumi.set(__self__, "table", table)

    @property
    @pulumi.getter
    def column(self) -> Optional[pulumi.Input[str]]:
        """
        The name of column.
        """
        return pulumi.get(self, "column")

    @column.setter
    def column(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "column", value)

    @property
    @pulumi.getter
    def database(self) -> Optional[pulumi.Input[str]]:
        """
        The name of database.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database", value)

    @property
    @pulumi.getter
    def table(self) -> Optional[pulumi.Input[str]]:
        """
        The name of table.
        """
        return pulumi.get(self, "table")

    @table.setter
    def table(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "table", value)


